package fslog

import (
	"go.uber.org/zap"
	"testing"
)

// 性能对比（在进行仅控制台打印前提下）：
// fslog:
// 63.29 ns/op           16 B/op          1 allocs/op
// zap:
// 10.10 ns/op            0 B/op          0 allocs/op
// 在有额外文件输出时，fslog性能为：
// 70.65 ns/op           16 B/op          1 allocs/op

func BenchmarkFSLog(b *testing.B) {
	SetLv(ErrorLv)
	b.Run("fslog", func(b *testing.B) {
		b.ReportAllocs()
		for i := 0; i < b.N; i++ {
			Debug("fslog")
		}
		b.StopTimer()
	})

	production, err := zap.NewProduction()
	if err != nil {
		b.Fatal(err)
	}
	zapLogger := production.Sugar()
	b.Run("zap", func(b *testing.B) {
		b.ReportAllocs()
		for i := 0; i < b.N; i++ {
			zapLogger.Debug("zap")
		}
		b.StopTimer()
	})
}
